# Fustor Bio-Fusion Demo - Unified Directory API Explorer

### Source Controls (Simulated Agents)

MySQL (Projects) Online
New project: {{ mysqlProjectName }}
NFS Hot (Raw Data) Online
NFS Cold (Archived Data) Online
OSS (Public Datasets) Online
ES (PubMed Publications) Online

### Unified Directory API Explorer

API Endpoint
GET

#### API Response

Loading...
{{ error }}

Name | Type | Logical Path | Source | Size | Last Modified | URL / Details
--- | --- | --- | --- | --- | --- | ---
No data available. Create some projects and items!

    {{ JSON.stringify(unifiedDirectory, null, 2) }}